import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as RolesAPI from 'cloudflare/resources/accounts/roles';
import { SinglePage } from 'cloudflare/pagination';
export declare class Roles extends APIResource {
    /**
     * Get all available roles for an account.
     */
    list(params: RoleListParams, options?: Core.RequestOptions): Core.PagePromise<RolesSinglePage, Role>;
    /**
     * Get information about a specific role for an account.
     */
    get(roleId: unknown, params: RoleGetParams, options?: Core.RequestOptions): Core.APIPromise<RoleGetResponse>;
}
export declare class RolesSinglePage extends SinglePage<Role> {
}
export interface Role {
    /**
     * Role identifier tag.
     */
    id: string;
    /**
     * Description of role's permissions.
     */
    description: string;
    /**
     * Role Name.
     */
    name: string;
    /**
     * Access permissions for this User.
     */
    permissions: Array<string>;
}
export type RoleGetResponse = unknown | string | null;
export interface RoleListParams {
    account_id: unknown;
}
export interface RoleGetParams {
    account_id: unknown;
}
export declare namespace Roles {
    export import Role = RolesAPI.Role;
    export import RoleGetResponse = RolesAPI.RoleGetResponse;
    export import RolesSinglePage = RolesAPI.RolesSinglePage;
    export import RoleListParams = RolesAPI.RoleListParams;
    export import RoleGetParams = RolesAPI.RoleGetParams;
}
//# sourceMappingURL=roles.d.ts.map