import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as VersionsAPI from 'cloudflare/resources/rulesets/versions/versions';
import * as RulesetsAPI from 'cloudflare/resources/rulesets/rulesets';
import * as ByTagAPI from 'cloudflare/resources/rulesets/versions/by-tag';
import { SinglePage } from 'cloudflare/pagination';
export declare class Versions extends APIResource {
    byTag: ByTagAPI.ByTag;
    /**
     * Fetches the versions of an account or zone ruleset.
     */
    list(rulesetId: string, params?: VersionListParams, options?: Core.RequestOptions): Core.PagePromise<VersionListResponsesSinglePage, VersionListResponse>;
    list(rulesetId: string, options?: Core.RequestOptions): Core.PagePromise<VersionListResponsesSinglePage, VersionListResponse>;
    /**
     * Deletes an existing version of an account or zone ruleset.
     */
    delete(rulesetId: string, rulesetVersion: string, params?: VersionDeleteParams, options?: Core.RequestOptions): Core.APIPromise<void>;
    delete(rulesetId: string, rulesetVersion: string, options?: Core.RequestOptions): Core.APIPromise<void>;
    /**
     * Fetches a specific version of an account or zone ruleset.
     */
    get(rulesetId: string, rulesetVersion: string, params?: VersionGetParams, options?: Core.RequestOptions): Core.APIPromise<RulesetsAPI.Ruleset>;
    get(rulesetId: string, rulesetVersion: string, options?: Core.RequestOptions): Core.APIPromise<RulesetsAPI.Ruleset>;
}
export declare class VersionListResponsesSinglePage extends SinglePage<VersionListResponse> {
}
/**
 * A ruleset object.
 */
export interface VersionListResponse {
    /**
     * The kind of the ruleset.
     */
    kind: 'managed' | 'custom' | 'root' | 'zone';
    /**
     * The human-readable name of the ruleset.
     */
    name: string;
    /**
     * The phase of the ruleset.
     */
    phase: 'ddos_l4' | 'ddos_l7' | 'http_config_settings' | 'http_custom_errors' | 'http_log_custom_fields' | 'http_ratelimit' | 'http_request_cache_settings' | 'http_request_dynamic_redirect' | 'http_request_firewall_custom' | 'http_request_firewall_managed' | 'http_request_late_transform' | 'http_request_origin' | 'http_request_redirect' | 'http_request_sanitize' | 'http_request_sbfm' | 'http_request_select_configuration' | 'http_request_transform' | 'http_response_compression' | 'http_response_firewall_managed' | 'http_response_headers_transform' | 'magic_transit' | 'magic_transit_ids_managed' | 'magic_transit_managed';
    /**
     * The unique ID of the ruleset.
     */
    id?: string;
    /**
     * An informative description of the ruleset.
     */
    description?: string;
    /**
     * The timestamp of when the ruleset was last modified.
     */
    last_updated?: string;
    /**
     * The version of the ruleset.
     */
    version?: string;
}
export interface VersionListParams {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    account_id?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zone_id?: string;
}
export interface VersionDeleteParams {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    account_id?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zone_id?: string;
}
export interface VersionGetParams {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    account_id?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zone_id?: string;
}
export declare namespace Versions {
    export import VersionListResponse = VersionsAPI.VersionListResponse;
    export import VersionListResponsesSinglePage = VersionsAPI.VersionListResponsesSinglePage;
    export import VersionListParams = VersionsAPI.VersionListParams;
    export import VersionDeleteParams = VersionsAPI.VersionDeleteParams;
    export import VersionGetParams = VersionsAPI.VersionGetParams;
    export import ByTag = ByTagAPI.ByTag;
    export import ByTagGetParams = ByTagAPI.ByTagGetParams;
}
//# sourceMappingURL=versions.d.ts.map