import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as BookmarksAPI from 'cloudflare/resources/zero-trust/access/bookmarks';
import { SinglePage } from 'cloudflare/pagination';
export declare class Bookmarks extends APIResource {
    /**
     * Create a new Bookmark application.
     */
    create(identifier: string, uuid: string, options?: Core.RequestOptions): Core.APIPromise<ZeroTrustBookmarks>;
    /**
     * Updates a configured Bookmark application.
     */
    update(identifier: string, uuid: string, options?: Core.RequestOptions): Core.APIPromise<ZeroTrustBookmarks>;
    /**
     * Lists Bookmark applications.
     */
    list(identifier: string, options?: Core.RequestOptions): Core.PagePromise<ZeroTrustBookmarksSinglePage, ZeroTrustBookmarks>;
    /**
     * Deletes a Bookmark application.
     */
    delete(identifier: string, uuid: string, options?: Core.RequestOptions): Core.APIPromise<BookmarkDeleteResponse>;
    /**
     * Fetches a single Bookmark application.
     */
    get(identifier: string, uuid: string, options?: Core.RequestOptions): Core.APIPromise<ZeroTrustBookmarks>;
}
export declare class ZeroTrustBookmarksSinglePage extends SinglePage<ZeroTrustBookmarks> {
}
export interface ZeroTrustBookmarks {
    /**
     * The unique identifier for the Bookmark application.
     */
    id?: string;
    /**
     * Displays the application in the App Launcher.
     */
    app_launcher_visible?: boolean;
    created_at?: string;
    /**
     * The domain of the Bookmark application.
     */
    domain?: string;
    /**
     * The image URL for the logo shown in the App Launcher dashboard.
     */
    logo_url?: string;
    /**
     * The name of the Bookmark application.
     */
    name?: string;
    updated_at?: string;
}
export interface BookmarkDeleteResponse {
    /**
     * UUID
     */
    id?: string;
}
export declare namespace Bookmarks {
    export import ZeroTrustBookmarks = BookmarksAPI.ZeroTrustBookmarks;
    export import BookmarkDeleteResponse = BookmarksAPI.BookmarkDeleteResponse;
    export import ZeroTrustBookmarksSinglePage = BookmarksAPI.ZeroTrustBookmarksSinglePage;
}
//# sourceMappingURL=bookmarks.d.ts.map