import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as IncludesAPI from 'cloudflare/resources/zero-trust/devices/policies/includes';
import { SinglePage } from 'cloudflare/pagination';
export declare class Includes extends APIResource {
    /**
     * Sets the list of routes included in the WARP client's tunnel.
     */
    update(params: IncludeUpdateParams, options?: Core.RequestOptions): Core.APIPromise<IncludeUpdateResponse | null>;
    /**
     * Fetches the list of routes included in the WARP client's tunnel.
     */
    list(params: IncludeListParams, options?: Core.RequestOptions): Core.PagePromise<DevicesSplitTunnelIncludesSinglePage, DevicesSplitTunnelInclude>;
    /**
     * Fetches the list of routes included in the WARP client's tunnel for a specific
     * device settings profile.
     */
    get(policyId: string, params: IncludeGetParams, options?: Core.RequestOptions): Core.APIPromise<IncludeGetResponse | null>;
}
export declare class DevicesSplitTunnelIncludesSinglePage extends SinglePage<DevicesSplitTunnelInclude> {
}
export interface DevicesSplitTunnelInclude {
    /**
     * The address in CIDR format to include in the tunnel. If address is present, host
     * must not be present.
     */
    address: string;
    /**
     * A description of the split tunnel item, displayed in the client UI.
     */
    description: string;
    /**
     * The domain name to include in the tunnel. If host is present, address must not
     * be present.
     */
    host?: string;
}
export type IncludeUpdateResponse = Array<DevicesSplitTunnelInclude>;
export type IncludeGetResponse = Array<DevicesSplitTunnelInclude>;
export interface IncludeUpdateParams {
    /**
     * Path param:
     */
    account_id: string;
    /**
     * Body param:
     */
    body: Array<DevicesSplitTunnelInclude>;
}
export interface IncludeListParams {
    account_id: string;
}
export interface IncludeGetParams {
    account_id: string;
}
export declare namespace Includes {
    export import DevicesSplitTunnelInclude = IncludesAPI.DevicesSplitTunnelInclude;
    export import IncludeUpdateResponse = IncludesAPI.IncludeUpdateResponse;
    export import IncludeGetResponse = IncludesAPI.IncludeGetResponse;
    export import DevicesSplitTunnelIncludesSinglePage = IncludesAPI.DevicesSplitTunnelIncludesSinglePage;
    export import IncludeUpdateParams = IncludesAPI.IncludeUpdateParams;
    export import IncludeListParams = IncludesAPI.IncludeListParams;
    export import IncludeGetParams = IncludesAPI.IncludeGetParams;
}
//# sourceMappingURL=includes.d.ts.map