import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as DNSSettingsAPI from 'cloudflare/resources/zones/dns-settings';
export declare class DNSSettings extends APIResource {
    /**
     * Update DNS settings for a zone
     */
    edit(params: DNSSettingEditParams, options?: Core.RequestOptions): Core.APIPromise<DNSSettingEditResponse>;
    /**
     * Show DNS settings for a zone
     */
    get(params: DNSSettingGetParams, options?: Core.RequestOptions): Core.APIPromise<DNSSettingGetResponse>;
}
export interface DNSSettingEditResponse {
    /**
     * Settings determining the nameservers through which the zone should be available.
     */
    nameservers?: DNSSettingEditResponse.Nameservers;
}
export declare namespace DNSSettingEditResponse {
    /**
     * Settings determining the nameservers through which the zone should be available.
     */
    interface Nameservers {
        /**
         * Nameserver type
         */
        type: 'cloudflare.standard' | 'cloudflare.foundation_dns';
    }
}
export interface DNSSettingGetResponse {
    /**
     * Settings determining the nameservers through which the zone should be available.
     */
    nameservers?: DNSSettingGetResponse.Nameservers;
}
export declare namespace DNSSettingGetResponse {
    /**
     * Settings determining the nameservers through which the zone should be available.
     */
    interface Nameservers {
        /**
         * Nameserver type
         */
        type: 'cloudflare.standard' | 'cloudflare.foundation_dns';
    }
}
export interface DNSSettingEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Settings determining the nameservers through which the zone should
     * be available.
     */
    nameservers?: DNSSettingEditParams.Nameservers;
}
export declare namespace DNSSettingEditParams {
    /**
     * Settings determining the nameservers through which the zone should be available.
     */
    interface Nameservers {
        /**
         * Nameserver type
         */
        type: 'cloudflare.standard' | 'cloudflare.foundation_dns';
    }
}
export interface DNSSettingGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace DNSSettings {
    export import DNSSettingEditResponse = DNSSettingsAPI.DNSSettingEditResponse;
    export import DNSSettingGetResponse = DNSSettingsAPI.DNSSettingGetResponse;
    export import DNSSettingEditParams = DNSSettingsAPI.DNSSettingEditParams;
    export import DNSSettingGetParams = DNSSettingsAPI.DNSSettingGetParams;
}
//# sourceMappingURL=dns-settings.d.ts.map