import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as CiphersAPI from 'cloudflare/resources/zones/settings/ciphers';
export declare class Ciphers extends APIResource {
    /**
     * Changes ciphers setting.
     */
    edit(params: CipherEditParams, options?: Core.RequestOptions): Core.APIPromise<ZoneSettingCiphers>;
    /**
     * Gets ciphers setting.
     */
    get(params: CipherGetParams, options?: Core.RequestOptions): Core.APIPromise<ZoneSettingCiphers>;
}
/**
 * An allowlist of ciphers for TLS termination. These ciphers must be in the
 * BoringSSL format.
 */
export interface ZoneSettingCiphers {
    /**
     * ID of the zone setting.
     */
    id: 'ciphers';
    /**
     * Current value of the zone setting.
     */
    value: Array<string>;
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export interface CipherEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Value of the zone setting.
     */
    value: Array<string>;
}
export interface CipherGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace Ciphers {
    export import ZoneSettingCiphers = CiphersAPI.ZoneSettingCiphers;
    export import CipherEditParams = CiphersAPI.CipherEditParams;
    export import CipherGetParams = CiphersAPI.CipherGetParams;
}
//# sourceMappingURL=ciphers.d.ts.map